==> peperit_2.0_estable.zip: themes/peperit/html_files/componentes/contacto/datos_contacto.php <==
<?php
//---------------------------------------------------------------------------------------------------------
// 23/OCTUBRE/2019
// Versión 1.0 Apartado para los datos de contacto
// Tatiana: creo este fichero para personalizar solo estos datos cuando asi sea necesario.
//---------------------------------------------------------------------------------------------------------
?>

            <section class="contact-form-box">
                <div class="mapa_contacto">
                    <?= Shop::$empresa->iframe_gmaps; ?>
                </div>
                <h3 class="datos">
                    <span class="mdi mdi-home"></span> <?= Shop::$empresa->nombre; ?>
                </h3>
                <p>
                    <span class="mdi mdi-map-marker"></span>
                    <?= Shop::$empresa->direccion; ?> <span class=""><?= Shop::$empresa->cod_postal; ?>, </span>
                    <span class=""><?= Shop::$empresa->localidad; ?>, </span>
                    <span class=""><?= Shop::$empresa->provincia; ?>.</span>
                </p>
                <p><span class="mdi mdi-gmail"></span> <a href="mailto:<?= Shop::$empresa->direccion_email; ?>"><?= Shop::$empresa->direccion_email; ?></a></p>
                <p><span class="mdi mdi-phone"></span> <a href="tel:<?= Shop::$empresa->telefono_empresa; ?>"> <?= Shop::$empresa->telefono_empresa; ?></a> </p>
                <h3><?=traducir('Horario');?></h3>
                <div class="horario">
				<?= traducir('%-Shop::$empresa->horario-%');?>
                </div>
<script>
//Pedro 23/Octubre/2019 ==> Hacemos esta función para esta plantilla. Dividimos el horario en las líneas que sea si hay un \n para meterlas en párrafos diferentes
document.addEventListener('WSLE', function(){
    var horario = $('.horario').html();
    //console.log(horario);
    horario = horario.split("\\n");
    $('.horario').html('');
    horario.forEach(function(element) {
        var p = $('<p>');
        p.html(' ' + element);
        var span = $('<span>');
        span.addClass('mdi');
        span.addClass('mdi-clock');
        p.prepend(span);
        $('.horario').append(p);
    });
});
</script>


                 <h3><?=traducir('Síguenos en las redes sociales');?></h3>
                 <?php 
               new Widget($_WH->GW("redes_sociales","redes_sociales"), new OpcionesWidget(array("ficheroRedSocial" => "itemSocialMedia")));
               ?>
            </section>

==> peperit_2.1_estable.zip: themes/peperit/html_files/componentes/contacto/datos_contacto.php <==
<?php
//---------------------------------------------------------------------------------------------------------
// 23/OCTUBRE/2019
// Versión 1.0 Apartado para los datos de contacto
// Tatiana: creo este fichero para personalizar solo estos datos cuando asi sea necesario.
//---------------------------------------------------------------------------------------------------------
?>
<?php
//Marina (18/08/2020) comparo localidad y provincia para ver si son iguales, si es así una la dejo vacía.
$localidad = Shop::$empresa->localidad;
$provincia = Shop::$empresa->provincia;
if(strtolower($localidad) == strtolower($provincia)){
    $localidad ='';
}else{
     $localidad .=',';
}
?>

            <section class="contact-form-box">
                <div class="mapa_contacto">
                    <?= Shop::$empresa->iframe_gmaps; ?>
                </div>
                <h3 class="datos">
                    <span class="mdi mdi-home"></span> <?= Shop::$empresa->nombre; ?>
                </h3>
                <p>
                    <span class="mdi mdi-map-marker"></span>
                    <?= Shop::$empresa->direccion; ?> <span class=""><?= Shop::$empresa->cod_postal; ?>, </span>
                    <span class=""><?= $localidad; ?>, </span>
                    <span class=""><?= $provincia; ?>.</span>
                </p>
                <p><span class="mdi mdi-gmail"></span> <a href="mailto:<?= Shop::$empresa->direccion_email; ?>"><?= Shop::$empresa->direccion_email; ?></a></p>
                <p><span class="mdi mdi-phone"></span> <a href="tel:<?= Shop::$empresa->telefono_empresa; ?>"> <?= Shop::$empresa->telefono_empresa; ?></a> </p>
                <h3><?=traducir('Horario');?></h3>
                <div class="horario">
				<?= traducir('%-Shop::$empresa->horario-%');?>
                </div>
<script>
//Pedro 23/Octubre/2019 ==> Hacemos esta función para esta plantilla. Dividimos el horario en las líneas que sea si hay un \n para meterlas en párrafos diferentes
document.addEventListener('WSLE', function(){
    var horario = $('.horario').html();
    //console.log(horario);
    horario = horario.split("\\n");
    $('.horario').html('');
    horario.forEach(function(element) {
        var p = $('<p>');
        p.html(' ' + element);
        var span = $('<span>');
        span.addClass('mdi');
        span.addClass('mdi-clock');
        p.prepend(span);
        $('.horario').append(p);
    });
});
</script>


                 <h3><?=traducir('Síguenos en las redes sociales');?></h3>
                 <?php 
               new Widget($_WH->GW("redes_sociales","redes_sociales"), new OpcionesWidget(array("ficheroRedSocial" => "itemSocialMedia")));
               ?>
            </section>
